@@ -13,7 +13,7 @@
 #' If the package is loaded, it will be reloaded after installation. This is
 #' not always completely possible, see \code{\link{reload}} for caveats.
 #'
-#' To install a package in a non-default library, use \code{\link{with_libpaths}}.
+#' To install a package in a non-default library, use \code{\link[withr]{with_libpaths}}.
 #'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
@@ -45,6 +45,10 @@
 #' @param threads number of concurrent threads to use for installing
 #'   dependencies.
 #'   It defaults to the option \code{"Ncpus"} or \code{1} if unset.
+#' @param force_deps whether to force installation of dependencies even if their
+#'   SHA1 reference hasn't changed from the currently installed version.
+#' @param metadata Named list of metadata entries to be added to the
+#'   \code{DESCRIPTION} after installation.
 #' @param ... additional arguments passed to \code{\link{install.packages}}
 #'   when installing dependencies. \code{pkg} is installed with
 #'   \code{R CMD INSTALL}.
@@ -58,11 +62,20 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
                     build_vignettes = FALSE,
                     keep_source = getOption("keep.source.pkgs"),
                     threads = getOption("Ncpus", 1),
+                    force_deps = FALSE,
+                    metadata = remote_metadata(as.package(pkg)),
                     ...) {
 
   pkg <- as.package(pkg)
   check_build_tools(pkg)
 
+  # Forcing all of the promises for the current namespace now will avoid lazy-load
+  # errors when the new package is installed overtop the old one.
+  # https://stat.ethz.ch/pipermail/r-devel/2015-December/072150.html
+  if (is_loaded(pkg)) {
+    eapply(ns_env(pkg), force, all.names = TRUE)
+  }
+
   if (!quiet) {
     message("Installing ", pkg$package)
   }
@@ -72,7 +85,7 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
     dependencies <- TRUE
   }
   install_deps(pkg, dependencies = dependencies, upgrade = upgrade_dependencies,
-    threads = threads, ...)
+    threads = threads, force_deps = force_deps, ...)
 
   # Build the package. Only build locally if it doesn't have vignettes
   has_vignettes <- length(tools::pkgVignettes(dir = pkg$path)$docs > 0)
@@ -97,6 +110,10 @@ install <- function(pkg = ".", reload = TRUE, quick = FALSE, local = TRUE,
   R(paste("CMD INSTALL ", shQuote(built_path), " ", opts, sep = ""),
     quiet = quiet)
 
+  if (length(metadata) > 0) {
+    add_metadata(inst(pkg$package), metadata)
+  }
+
   if (reload) {
     reload(pkg, quiet = quiet)
   }
@@ -117,9 +134,10 @@ install_deps <- function(pkg = ".", dependencies = NA,
                          type = getOption("pkgType"),
                          ...,
                          upgrade = TRUE,
-                         quiet = FALSE) {
+                         quiet = FALSE,
+                         force_deps = FALSE) {
 
   pkg <- dev_package_deps(pkg, repos = repos, dependencies = dependencies,
-    type = type)
+    type = type, force_deps = force_deps)
   update(pkg, ..., Ncpus = threads, quiet = quiet, upgrade = upgrade)
 }
