@@ -113,8 +113,14 @@ assignNativeRoutines <- function(dll, lib, env, nativeRoutines) {
   if(length(symNames) == 0L)
     return(NULL)
 
-  symbols <- getNativeSymbolInfo(symNames, dll, unlist = FALSE,
-                                     withRegistrationInfo = TRUE)
+
+  symbols <- tryCatch(
+    getNativeSymbolInfo(symNames, dll, unlist = FALSE, withRegistrationInfo = TRUE),
+    error = function(.) {
+      warning("Failed to load native symbol info", call. = FALSE)
+      list()
+    }
+  )
   lapply(seq_along(symNames),
     function(i) {
       ## could vectorize this outside of the loop
