@@ -42,7 +42,53 @@ render_template <- function(name, data = list()) {
 }
 
 is_installed <- function(pkg, version = 0) {
-  system.file(package = pkg) != "" && packageVersion(pkg) > version
+  installed_version <- tryCatch(utils::packageVersion(pkg), error = function(e) NA)
+  !is.na(installed_version) && installed_version >= version
+}
+
+check_suggested <- function(pkg, version = NULL, compare = NA) {
+
+  if (is.null(version)) {
+    if (!is.na(compare)) {
+      stop("Cannot set ", sQuote(compare), " without setting ",
+           sQuote(version), call. = FALSE)
+    }
+
+    dep <- suggests_dep(pkg)
+
+    version <- dep$version
+    compare <- dep$compare
+  }
+
+  if (!check_dep_version(pkg, version, compare)) {
+    msg <- paste0(sQuote(pkg),
+      if (version == 0) "" else paste0(" >= ", version),
+      " must be installed for this functionality.")
+
+    if (interactive()) {
+      message(msg, "\nWould you like to install it?")
+      if (menu(c("Yes", "No")) == 1) {
+        install.packages(pkg)
+      } else {
+        stop(msg, call. = FALSE)
+      }
+    } else {
+      stop(msg, call. = FALSE)
+    }
+  }
+}
+
+suggests_dep <- function(pkg) {
+
+  suggests <- read_dcf(system.file("DESCRIPTION", package = "devtools"))$Suggests
+  deps <- parse_deps(suggests)
+
+  found <- which(deps$name == pkg)[1L]
+
+  if (!length(found)) {
+     stop(sQuote(pkg), " is not in Suggests: for devtools!", call. = FALSE)
+  }
+  deps[found, ]
 }
 
 read_dcf <- function(path) {
@@ -56,7 +102,9 @@ write_dcf <- function(path, desc) {
   desc <- gsub("\n[ \t]*\n", "\n .\n ", desc, perl = TRUE, useBytes = TRUE)
   desc <- gsub("\n \\.([^\n])", "\n  .\\1", desc, perl = TRUE, useBytes = TRUE)
 
-  text <- paste0(names(desc), ": ", desc, collapse = "\n")
+  starts_with_whitespace <- grepl("^\\s", desc, perl = TRUE, useBytes = TRUE)
+  delimiters <- ifelse(starts_with_whitespace, ":", ": ")
+  text <- paste0(names(desc), delimiters, desc, collapse = "\n")
 
   if (substr(text, nchar(text), 1) != "\n") {
     text <- paste0(text, "\n")
@@ -99,7 +147,7 @@ file_ext <- function (x) {
 }
 
 is_bioconductor <- function(x) {
-  !is.null(x$biocviews)
+  x$package != "BiocInstaller" && !is.null(x$biocviews)
 }
 
 trim_ws <- function(x) {
